aboutsummaryrefslogtreecommitdiffstats
path: root/vendor/github.com/allegro/bigcache/entry_not_found_error.go
diff options
context:
space:
mode:
Diffstat (limited to 'vendor/github.com/allegro/bigcache/entry_not_found_error.go')
-rw-r--r--vendor/github.com/allegro/bigcache/entry_not_found_error.go17
1 files changed, 3 insertions, 14 deletions
diff --git a/vendor/github.com/allegro/bigcache/entry_not_found_error.go b/vendor/github.com/allegro/bigcache/entry_not_found_error.go
index 883bdc29e..051a71230 100644
--- a/vendor/github.com/allegro/bigcache/entry_not_found_error.go
+++ b/vendor/github.com/allegro/bigcache/entry_not_found_error.go
@@ -1,17 +1,6 @@
package bigcache
-import "fmt"
+import "errors"
-// EntryNotFoundError is an error type struct which is returned when entry was not found for provided key
-type EntryNotFoundError struct {
- key string
-}
-
-func notFound(key string) error {
- return &EntryNotFoundError{key}
-}
-
-// Error returned when entry does not exist.
-func (e EntryNotFoundError) Error() string {
- return fmt.Sprintf("Entry %q not found", e.key)
-}
+// ErrEntryNotFound is an error type struct which is returned when entry was not found for provided key
+var ErrEntryNotFound = errors.New("Entry not found")